@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -51,9 +51,9 @@ import com.jgoodies.forms.layout.RowSpec;
  * and logical columns and rows.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.9 $
+ * @version $Revision: 1.12 $
  *
- * @see    ButtonBarBuilder
+ * @see    ButtonBarBuilder2
  * @see    ButtonStackBuilder
  * @see    PanelBuilder
  * @see    I15dPanelBuilder
@@ -554,7 +554,7 @@ public abstract class AbstractFormBuilder {
      * @param cellConstraints  the component's cell constraints
      * @return the added component
      */
-    public final Component add(Component component, CellConstraints cellConstraints) {
+    public Component add(Component component, CellConstraints cellConstraints) {
         container.add(component, cellConstraints);
         return component;
     }
