@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -36,8 +36,6 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Map.Entry;
 
-import javax.swing.UIManager;
-
 import com.jgoodies.forms.factories.FormFactory;
 import com.jgoodies.forms.util.LayoutStyle;
 
@@ -63,13 +61,14 @@ import com.jgoodies.forms.util.LayoutStyle;
  *
  * By default the root LayoutMap provides the following associations:
  * <table border="1">
- * <tr><td><b>Variable Name</b><td><b>Abbreviations</b></td><td><b>Value</b></td></tr>
- * <tr><td>label-component-gap</td><td>lcg, lcgap</td><td>gap between a label and its component</td></tr>
- * <tr><td>related-gap</td><td>rg, rgap</td><td>gap between two related components</td></tr>
- * <tr><td>unrelated-gap</td><td>ug, ugap</td><td>gap between two unrelated components</td></tr>
- * <tr><td>line-gap</td><td>lg, lgap</td><td>gap between two lines</td></tr>
- * <tr><td>narrow-line-gap</td><td>nlg, nlgap</td><td>narrow gap between two lines</td></tr>
- * <tr><td>paragraph</td><td>pg, pgap</td><td>gap between two paragraphs/sections</td></tr>
+ * <tr><td><b>Variable Name</b><td><b>Abbreviations</b></td><td><b>Orientation</b></td><td><b>Description</b></td></tr>
+ * <tr><td>label-component-gap</td><td>lcg, lcgap</td><td>horizontal</td><td>gap between a label and its component</td></tr>
+ * <tr><td>button</td><td>b</td><td>horizontal</td><td>button column with minimum width</td></tr>
+ * <tr><td>related-gap</td><td>rg, rgap</td><td>both</td><td>gap between two related components</td></tr>
+ * <tr><td>unrelated-gap</td><td>ug, ugap</td><td>both</td><td>gap between two unrelated components</td></tr>
+ * <tr><td>line-gap</td><td>lg, lgap</td><td>vertical</td><td>gap between two lines</td></tr>
+ * <tr><td>narrow-line-gap</td><td>nlg, nlgap</td><td>vertical</td><td>narrow gap between two lines</td></tr>
+ * <tr><td>paragraph</td><td>pg, pgap</td><td>vertical</td><td>gap between two paragraphs/sections</td></tr>
  * </table><p>
  *
  * <strong>Examples:</strong>
@@ -109,7 +108,7 @@ import com.jgoodies.forms.util.LayoutStyle;
  * </ul>
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.14 $
+ * @version $Revision: 1.18 $
  *
  * @see     FormLayout
  * @see     ColumnSpec
@@ -125,14 +124,6 @@ public final class LayoutMap {
     private static final char VARIABLE_PREFIX_CHAR = '$';
 
 
-    /**
-     * The key used to look up the default LayoutMap from the UIManager.
-     *
-     * @see #setRoot(LayoutMap)
-     */
-    private static final String LAYOUT_MAP_KEY = "JGoodiesFormsDefaultLayoutMap";
-
-
     /**
      * Maps column aliases to their default name, for example
      * {@code "rgap"} -> {@code "related-gap"}.
@@ -149,6 +140,12 @@ public final class LayoutMap {
         = new HashMap/*<String, String>*/();
 
 
+    /**
+     * Holds the lazily initialized root map.
+     */
+    private static LayoutMap root = null;
+
+
     // Instance Fields ********************************************************
 
     /**
@@ -211,42 +208,18 @@ public final class LayoutMap {
 
     /**
      * Lazily initializes and returns the LayoutMap that is used
-     * for variable expansion, if no custom LayoutMap is provided.<p>
-     *
-     * The root LayoutMap is stored in the UIManager that in turn uses
-     * an AppContext to store the values. This way applets in different
-     * contexts uses different defaults.
+     * for variable expansion, if no custom LayoutMap is provided.
      *
      * @return the LayoutMap that is used, if no custom LayoutMap is provided
      */
     public static LayoutMap getRoot() {
-        LayoutMap root = (LayoutMap) UIManager.get(LAYOUT_MAP_KEY);
         if (root == null) {
             root = createRoot();
-            setRoot(root);
         }
         return root;
     }
 
 
-    /**
-     * Sets the given LayoutMap as new root. The root LayoutMap is used as
-     * default for variable expansion, if no custom LayoutMap is provided.<p>
-     *
-     * Custom variables can be set in the root LayoutMap, or in child maps
-     * that are provided as argument for the FormLayout, ColumnSpec, and
-     * RowSpec constructors/factory methods.<p>
-     *
-     * The root LayoutMap is stored using an AppContext; hence applets
-     * in different contexts uses different defaults.
-     *
-     * @param root   the LayoutMap to become the new root
-     */
-    private static void setRoot(LayoutMap root) {
-        UIManager.put(LAYOUT_MAP_KEY, root);
-    }
-
-
     // Column Mapping *********************************************************
 
     /**
@@ -495,7 +468,7 @@ public final class LayoutMap {
      * @return a string representation
      */
     public String toString() {
-        StringBuffer buffer = new StringBuffer("LayoutMap");
+        StringBuffer buffer = new StringBuffer(super.toString());
         buffer.append("\n  Column associations:");
         for (Iterator iterator = columnMap.entrySet().iterator(); iterator.hasNext();) {
             Entry name = (Entry) iterator.next();
@@ -599,79 +572,79 @@ public final class LayoutMap {
 
 
     private static LayoutMap createRoot() {
-        LayoutMap root = new LayoutMap(null);
+        LayoutMap map = new LayoutMap(null);
 
         // Column variables
-        root.columnPut(
+        map.columnPut(
                 "label-component-gap",
                 new String[]{"lcg", "lcgap"},
                 FormFactory.LABEL_COMPONENT_GAP_COLSPEC);
-        root.columnPut(
+        map.columnPut(
                 "related-gap",
                 new String[]{"rg", "rgap"},
                 FormFactory.RELATED_GAP_COLSPEC);
-        root.columnPut(
+        map.columnPut(
                 "unrelated-gap",
                 new String[]{"ug", "ugap"},
                 FormFactory.UNRELATED_GAP_COLSPEC);
-        root.columnPut(
+        map.columnPut(
                 "button",
                 new String[]{"b"},
                 FormFactory.BUTTON_COLSPEC);
-        root.columnPut(
+        map.columnPut(
                 "growing-button",
                 new String[]{"gb"},
                 FormFactory.GROWING_BUTTON_COLSPEC);
-        root.columnPut(
+        map.columnPut(
                 "dialog-margin",
                 new String[]{"dm", "dmargin"},
                 ColumnSpec.createGap(LayoutStyle.getCurrent().getDialogMarginX()));
-        root.columnPut(
+        map.columnPut(
                 "tabbed-dialog-margin",
                 new String[]{"tdm", "tdmargin"},
                 ColumnSpec.createGap(LayoutStyle.getCurrent().getTabbedDialogMarginX()));
-        root.columnPut(
+        map.columnPut(
                 "glue",
                 FormFactory.GLUE_COLSPEC.toShortString());
 
         // Row variables
-        root.rowPut(
+        map.rowPut(
                 "related-gap",
                 new String[]{"rg", "rgap"},
                 FormFactory.RELATED_GAP_ROWSPEC);
-        root.rowPut(
+        map.rowPut(
                 "unrelated-gap",
                 new String[]{"ug", "ugap"},
                 FormFactory.UNRELATED_GAP_ROWSPEC);
-        root.rowPut(
+        map.rowPut(
                 "narrow-line-gap",
                 new String[]{"nlg", "nlgap"},
                 FormFactory.NARROW_LINE_GAP_ROWSPEC);
-        root.rowPut(
+        map.rowPut(
                 "line-gap",
                 new String[]{"lg", "lgap"},
                 FormFactory.LINE_GAP_ROWSPEC);
-        root.rowPut(
+        map.rowPut(
                 "paragraph-gap",
                 new String[]{"pg", "pgap"},
                 FormFactory.PARAGRAPH_GAP_ROWSPEC);
-        root.rowPut(
+        map.rowPut(
                 "dialog-margin",
                 new String[]{"dm", "dmargin"},
                 RowSpec.createGap(LayoutStyle.getCurrent().getDialogMarginY()));
-        root.rowPut(
+        map.rowPut(
                 "tabbed-dialog-margin",
                 new String[]{"tdm", "tdmargin"},
                 RowSpec.createGap(LayoutStyle.getCurrent().getTabbedDialogMarginY()));
-        root.rowPut(
+        map.rowPut(
                 "button",
                 new String[]{"b"},
                 FormFactory.BUTTON_ROWSPEC);
-        root.rowPut(
+        map.rowPut(
                 "glue",
                 FormFactory.GLUE_ROWSPEC);
 
-        return root;
+        return map;
     }
 
 
