@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -33,11 +33,9 @@ package com.jgoodies.forms.util;
 import java.awt.Component;
 import java.awt.Font;
 import java.awt.FontMetrics;
-import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
-import java.util.HashMap;
-import java.util.Map;
+import java.util.logging.Level;
 import java.util.logging.Logger;
 
 import javax.swing.JButton;
@@ -68,7 +66,7 @@ import javax.swing.UIManager;
  * Since the Forms 1.1 this converter logs font information at
  * the <code>CONFIG</code> level.
  *
- * @version $Revision: 1.13 $
+ * @version $Revision: 1.17 $
  * @author  Karsten Lentzsch
  * @see     UnitConverter
  * @see     com.jgoodies.forms.layout.Size
@@ -76,6 +74,13 @@ import javax.swing.UIManager;
  */
 public final class DefaultUnitConverter extends AbstractUnitConverter {
 
+    public static final String PROPERTY_AVERAGE_CHARACTER_WIDTH_TEST_STRING =
+        "averageCharacterWidthTestString";
+
+    public static final String PROPERTY_DEFAULT_DIALOG_FONT =
+        "defaultDialogFont";
+
+
 //    public static final String UPPERCASE_ALPHABET =
 //        "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 //
@@ -124,18 +129,22 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
     // Cached *****************************************************************
 
     /**
-     * Holds the cached global dialog base units that are used if
-     * a component is not (yet) available - for example in a Border.
+     * Holds the lazily created cached global dialog base units that are used
+     * if a component is not (yet) available - for example in a Border.
      */
-    private DialogBaseUnits cachedGlobalDialogBaseUnits =
-        computeGlobalDialogBaseUnits();
+    private DialogBaseUnits cachedGlobalDialogBaseUnits = null;
 
     /**
-     * Maps <code>FontMetrics</code> to horizontal dialog base units.
-     * This is a second-level cache, that stores dialog base units
-     * for a <code>FontMetrics</code> object.
+     * Holds the horizontal dialog base units that are valid
+     * for the FontMetrics stored in {@code cachedFontMetrics}.
      */
-    private final Map cachedDialogBaseUnits = new HashMap();
+    private DialogBaseUnits cachedDialogBaseUnits = null;
+
+    /**
+     * Holds the FontMetrics used to compute the per-component dialog units.
+     * The latter are valid, if a FontMetrics equals this stored metrics.
+     */
+    private FontMetrics cachedFontMetrics = null;
 
     /**
      * Holds a cached default dialog font that is used as fallback,
@@ -154,7 +163,6 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
      * a listener that handles changes in the look&amp;feel.
      */
     private DefaultUnitConverter() {
-        UIManager.addPropertyChangeListener(new LookAndFeelChangeHandler());
         changeSupport = new PropertyChangeSupport(this);
     }
 
@@ -199,15 +207,19 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
      * @throws NullPointerException     if the test string is <code>null</code>
      */
     public void setAverageCharacterWidthTestString(String newTestString) {
-        if (newTestString == null)
+        if (newTestString == null) {
             throw new NullPointerException("The test string must not be null.");
-        if (newTestString.length() == 0)
+        }
+        if (newTestString.length() == 0) {
             throw new IllegalArgumentException("The test string must not be empty.");
+        }
 
         String oldTestString = averageCharWidthTestString;
         averageCharWidthTestString = newTestString;
-        changeSupport.firePropertyChange("averageCharacterWidthTestString",
-            oldTestString, newTestString);
+        changeSupport.firePropertyChange(
+                PROPERTY_AVERAGE_CHARACTER_WIDTH_TEST_STRING,
+                oldTestString,
+                newTestString);
     }
 
 
@@ -233,8 +245,8 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
     public void setDefaultDialogFont(Font newFont) {
         Font oldFont = defaultDialogFont; // Don't use the getter
         defaultDialogFont = newFont;
-        invalidateCaches();
-        changeSupport.firePropertyChange("defaultDialogFont", oldFont, newFont);
+        clearCache();
+        changeSupport.firePropertyChange(PROPERTY_DEFAULT_DIALOG_FONT, oldFont, newFont);
     }
 
 
@@ -290,16 +302,18 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
      * @return the DialogBaseUnits object for the given component
      */
     private DialogBaseUnits getDialogBaseUnits(Component c) {
+        FormUtils.ensureValidCache();
         if (c == null) { // || (font = c.getFont()) == null) {
             // logInfo("Missing font metrics: " + c);
             return getGlobalDialogBaseUnits();
         }
         FontMetrics fm = c.getFontMetrics(getDefaultDialogFont());
-        DialogBaseUnits dialogBaseUnits = (DialogBaseUnits) cachedDialogBaseUnits.get(fm);
-        if (dialogBaseUnits == null) {
-            dialogBaseUnits = computeDialogBaseUnits(fm);
-            cachedDialogBaseUnits.put(fm, dialogBaseUnits);
+        if (fm.equals(cachedFontMetrics)) {
+            return cachedDialogBaseUnits;
         }
+        DialogBaseUnits dialogBaseUnits = computeDialogBaseUnits(fm);
+        cachedFontMetrics = fm;
+        cachedDialogBaseUnits = dialogBaseUnits;
         return dialogBaseUnits;
     }
 
@@ -326,11 +340,13 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
         double height = ascent > 14 ? ascent : ascent + (15 - ascent) / 3;
         DialogBaseUnits dialogBaseUnits =
             new DialogBaseUnits(averageCharWidth, height);
-        LOGGER.config(
-            "Computed dialog base units "
-                + dialogBaseUnits
-                + " for: "
-                + metrics.getFont());
+        if (LOGGER.isLoggable(Level.CONFIG)) {
+            LOGGER.config(
+                "Computed dialog base units "
+                    + dialogBaseUnits
+                    + " for: "
+                    + metrics.getFont());
+        }
         return dialogBaseUnits;
     }
 
@@ -360,6 +376,7 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
      * @return the cached fallback font used to compute the dialog base units
      */
     private Font getCachedDefaultDialogFont() {
+        FormUtils.ensureValidCache();
         if (cachedDefaultDialogFont == null) {
             cachedDefaultDialogFont = lookupDefaultDialogFont();
         }
@@ -402,9 +419,9 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
      * and resets the fallback for the default dialog font.
      * This is invoked after a change of the look&amp;feel.
      */
-    private void invalidateCaches() {
+    void clearCache() {
         cachedGlobalDialogBaseUnits = null;
-        cachedDialogBaseUnits.clear();
+        cachedFontMetrics = null;
         cachedDefaultDialogFont = null;
     }
 
@@ -511,13 +528,4 @@ public final class DefaultUnitConverter extends AbstractUnitConverter {
     }
 
 
-    /**
-     * Listens to changes of the Look and Feel and invalidates the cache.
-     */
-    private final class LookAndFeelChangeHandler implements PropertyChangeListener {
-        public void propertyChange(PropertyChangeEvent evt) {
-            invalidateCaches();
-        }
-    }
-
 }
