@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -39,7 +39,7 @@ import junit.framework.TestSuite;
  * A test suite for all tests related to the JGoodies Forms framework.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.18 $
+ * @version $Revision: 1.21 $
  */
 public final class AllFormsTests {
 
@@ -54,10 +54,12 @@ public final class AllFormsTests {
         return new TestSuite(new Class[]{
                 BordersTest.class,
                 CellConstraintsTest.class,
+                ClassLoaderTest.class,
                 ColumnSpecTest.class,
                 DefaultComponentFactoryTest.class,
                 FormLayoutTest.class,
                 FormLayoutGroupsTest.class,
+                PanelBuilderTest.class,
                 RowSpecTest.class,
                 SerializationTest.class,
                 UnitConversionTest.class
