@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -40,7 +40,7 @@ import com.jgoodies.forms.factories.FormFactory;
  * A test case for class {@link ColumnSpec}.
  *
  * @author	Karsten Lentzsch
- * @version $Revision: 1.32 $
+ * @version $Revision: 1.35 $
  */
 public final class ColumnSpecTest extends TestCase {
 
@@ -335,6 +335,12 @@ public final class ColumnSpecTest extends TestCase {
             assertEquals(2, specs.length);
             assertEquals(spec1, specs[0]);
             assertEquals(spec2, specs[1]);
+
+            spec2 = new ColumnSpec(new PrototypeSize("a,b"));
+            specs = ColumnSpec.decodeSpecs("l:p, 'a,b'");
+            assertEquals(2, specs.length);
+            assertEquals(spec1, specs[0]);
+            assertEquals(spec2, specs[1]);
         } finally {
             Locale.setDefault(oldDefault);
         }
@@ -354,14 +360,10 @@ public final class ColumnSpecTest extends TestCase {
             assertRejects("d:a:b:");
             assertRejects("top:default:grow");
             assertRejects("bottom:10px");
-            assertRejects("max(10px;20px)");
-            assertRejects("min(10px;20px)");
-            assertRejects("[10px,20px]");
             assertRejects("max(pref;pref)");
             assertRejects("min(pref;pref)");
             assertRejects("[pref,pref]");
             assertRejects("[pref,pref,200px]");  // lower bound must be constant
-            assertRejects("[10px,50px,200px]");  // basis must be logical
             assertRejects("[10px,pref,pref]");   // upper bound must be constant
 
             assertRejectsSpecs("7dlu l:p:g 7dlu");    // Missing commas
