@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -35,38 +35,40 @@ import java.awt.Insets;
 
 import javax.swing.*;
 
-import com.jgoodies.forms.builder.ButtonBarBuilder;
+import com.jgoodies.forms.builder.ButtonBarBuilder2;
 import com.jgoodies.forms.factories.Borders;
 import com.jgoodies.forms.layout.CellConstraints;
 import com.jgoodies.forms.layout.FormLayout;
+import com.jgoodies.forms.tutorial.util.TutorialApplication;
 
 /**
  * Demonstrates how to build button bars using a ButtonBarBuilder.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.25 $
+ * @version $Revision: 1.30 $
  *
- * @see     ButtonBarBuilder
+ * @see     ButtonBarBuilder2
  * @see     com.jgoodies.forms.factories.ButtonBarFactory
  */
-public final class ButtonBarsExample {
+public final class ButtonBarsExample extends TutorialApplication {
+
+
+    // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Forms Tutorial :: Button Bars");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new ButtonBarsExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        frame.setVisible(true);
+        TutorialApplication.launch(ButtonBarsExample.class, args);
     }
 
 
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Forms Tutorial :: Button Bars");
+        frame.getContentPane().add(buildPanel());
+        packAndShowOnScreenCenter(frame);
+    }
+
+
+    // Building ***************************************************************
+
     public JComponent buildPanel() {
         JTabbedPane tabbedPane = new JTabbedPane();
         tabbedPane.putClientProperty("jgoodies.noContentBorder", Boolean.TRUE);
@@ -94,12 +96,11 @@ public final class ButtonBarsExample {
     }
 
     private Component buildButtonBar2Panel() {
-        ButtonBarBuilder builder = new ButtonBarBuilder();
+        ButtonBarBuilder2 builder = new ButtonBarBuilder2();
         builder.addGlue();
-        builder.addGriddedButtons(new JButton[] {
+        builder.addButton(
                 new JButton("Yes"),
-                new JButton("No")
-                });
+                new JButton("No"));
         return wrap(builder.getPanel(),
             "This bar has been built with a ButtonBarBuilder:\n" +
             " o buttons have a minimum widths,\n" +
@@ -108,25 +109,25 @@ public final class ButtonBarsExample {
     }
 
     private Component buildButtonBar3Panel() {
-        ButtonBarBuilder builder = new ButtonBarBuilder();
+        ButtonBarBuilder2 builder = new ButtonBarBuilder2();
         builder.addGlue();
-        builder.addGridded(new JButton("One"));
+        builder.addButton(new JButton("One"));
         builder.addRelatedGap();
-        builder.addGridded(new JButton("Two"));
+        builder.addButton(new JButton("Two"));
         builder.addRelatedGap();
-        builder.addGridded(new JButton("Three"));
+        builder.addButton(new JButton("Three"));
         return wrap(builder.getPanel(),
             "This bar uses the logical gap for related buttons.\n");
     }
 
     private Component buildButtonBar4Panel() {
-        ButtonBarBuilder builder = new ButtonBarBuilder();
+        ButtonBarBuilder2 builder = new ButtonBarBuilder2();
         builder.addGlue();
-        builder.addGridded(new JButton("One"));
+        builder.addButton(new JButton("One"));
         builder.addUnrelatedGap();
-        builder.addGridded(new JButton("Two"));
+        builder.addButton(new JButton("Two"));
         builder.addUnrelatedGap();
-        builder.addGridded(new JButton("Three"));
+        builder.addButton(new JButton("Three"));
 
         return wrap(builder.getPanel(),
             "This bar uses the logical gap for unrelated buttons.\n" +
@@ -134,16 +135,15 @@ public final class ButtonBarsExample {
     }
 
     private Component buildButtonMixedBar1Panel() {
-        ButtonBarBuilder builder = new ButtonBarBuilder();
-        builder.addGridded(new JButton("Help"));
+        ButtonBarBuilder2 builder = new ButtonBarBuilder2();
+        builder.addButton(new JButton("Help"));
         builder.addUnrelatedGap();
         builder.addGlue();
         builder.addFixed(new JButton("Copy to Clipboard"));
         builder.addUnrelatedGap();
-        builder.addGriddedButtons(new JButton[] {
+        builder.addButton(
                 new JButton("OK"),
-                new JButton("Cancel")
-        	});
+                new JButton("Cancel"));
         return wrap(builder.getPanel(),
             "Demonstrates a glue (between Help and the rest),\n" +
             "has related and unrelated buttons and an ungridded button\n" +
@@ -151,16 +151,15 @@ public final class ButtonBarsExample {
     }
 
     private Component buildButtonMixedBar2Panel() {
-        ButtonBarBuilder builder = new ButtonBarBuilder();
-        builder.addGridded(new JButton("Help"));
+        ButtonBarBuilder2 builder = new ButtonBarBuilder2();
+        builder.addButton(new JButton("Help"));
         builder.addUnrelatedGap();
         builder.addGlue();
-        builder.addFixedNarrow(new JButton("Copy to Clipboard"));
+        builder.addButton(new JButton("Copy to Clipboard"));
         builder.addUnrelatedGap();
-        builder.addGriddedButtons(new JButton[] {
+        builder.addButton(
                 new JButton("OK"),
-                new JButton("Cancel")
-        });
+                new JButton("Cancel"));
         return wrap(builder.getPanel(),
             "Demonstrates a glue (between Help and the rest),\n" +
             "has related and unrelated buttons and an ungridded button\n" +
