@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -32,40 +32,44 @@ package com.jgoodies.forms.tutorial.building;
 
 import java.awt.Component;
 
-import javax.swing.*;
+import javax.swing.JButton;
+import javax.swing.JComponent;
+import javax.swing.JFrame;
 
-import com.jgoodies.forms.builder.ButtonBarBuilder;
+import com.jgoodies.forms.builder.ButtonBarBuilder2;
 import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
+import com.jgoodies.forms.tutorial.util.TutorialApplication;
 
 /**
  * Demonstrates how to build button bars with a fixed button order
  * or with a button order that honors the platform's style.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.10 $
+ * @version $Revision: 1.15 $
  *
- * @see     ButtonBarBuilder
+ * @see     ButtonBarBuilder2
  * @see     com.jgoodies.forms.factories.ButtonBarFactory
  */
-public final class ButtonOrderExample {
+public final class ButtonOrderExample extends TutorialApplication {
+
+
+    // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Forms Tutorial :: Button Order");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new ButtonOrderExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        frame.setVisible(true);
+        TutorialApplication.launch(ButtonOrderExample.class, args);
     }
 
 
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Forms Tutorial :: Button Order");
+        frame.getContentPane().add(buildPanel());
+        packAndShowOnScreenCenter(frame);
+    }
+
+
+    // Building ***************************************************************
+
     /**
      * Builds and returns a panel that consists of three paragraphs
      * that demonstrate different button orders. Each paragraph contains
@@ -80,16 +84,16 @@ public final class ButtonOrderExample {
         rowBuilder.setDefaultDialogBorder();
 
         rowBuilder.appendSeparator("Left to Right");
-        rowBuilder.append("Ordered", buildButtonSequence(ButtonBarBuilder.createLeftToRightBuilder()));
-        rowBuilder.append("Fixed",   buildIndividualButtons(ButtonBarBuilder.createLeftToRightBuilder()));
+        rowBuilder.append("Ordered:", buildButtonSequence(ButtonBarBuilder2.createLeftToRightBuilder()));
+        rowBuilder.append("Fixed:",   buildIndividualButtons(ButtonBarBuilder2.createLeftToRightBuilder()));
 
         rowBuilder.appendSeparator("Right to Left");
-        rowBuilder.append("Ordered", buildButtonSequence(createRightToLeftBuilder()));
-        rowBuilder.append("Fixed",   buildIndividualButtons(createRightToLeftBuilder()));
+        rowBuilder.append("Ordered:", buildButtonSequence(createRightToLeftBuilder()));
+        rowBuilder.append("Fixed:",   buildIndividualButtons(createRightToLeftBuilder()));
 
         rowBuilder.appendSeparator("Platform Default Order");
-        rowBuilder.append("Ordered", buildButtonSequence(new ButtonBarBuilder()));
-        rowBuilder.append("Fixed",   buildIndividualButtons(new ButtonBarBuilder()));
+        rowBuilder.append("Ordered:", buildButtonSequence(new ButtonBarBuilder2()));
+        rowBuilder.append("Fixed:",   buildIndividualButtons(new ButtonBarBuilder2()));
 
         return rowBuilder.getPanel();
     }
@@ -101,8 +105,8 @@ public final class ButtonOrderExample {
      * @param builder   the builder used to build the bar
      * @return a button bar that honors the builder's button order
      */
-    private Component buildButtonSequence(ButtonBarBuilder builder) {
-        builder.addGriddedButtons(new JButton[] {
+    private Component buildButtonSequence(ButtonBarBuilder2 builder) {
+        builder.addButton(new JButton[] {
                 new JButton("One"),
                 new JButton("Two"),
                 new JButton("Three")
@@ -118,12 +122,12 @@ public final class ButtonOrderExample {
      * @param builder   the builder used to build the bar
      * @return a button bar with a fixed left to right button order
      */
-    private Component buildIndividualButtons(ButtonBarBuilder builder) {
-        builder.addGridded(new JButton("One"));
+    private Component buildIndividualButtons(ButtonBarBuilder2 builder) {
+        builder.addButton(new JButton("One"));
         builder.addRelatedGap();
-        builder.addGridded(new JButton("Two"));
+        builder.addButton(new JButton("Two"));
         builder.addRelatedGap();
-        builder.addGridded(new JButton("Three"));
+        builder.addButton(new JButton("Three"));
         return builder.getPanel();
     }
 
@@ -131,13 +135,13 @@ public final class ButtonOrderExample {
     /**
      * Creates and returns a button bar builder with a fixed
      * right-to-left button order. Unlike the factory method
-     * {@link ButtonBarBuilder#createLeftToRightBuilder()}
+     * {@link ButtonBarBuilder2#createLeftToRightBuilder()}
      * this method is useful for demonstration purposes only.
      *
      * @return a ButtonBarBuilder with right-to-left button order
      */
-    private static ButtonBarBuilder createRightToLeftBuilder() {
-        ButtonBarBuilder builder = new ButtonBarBuilder();
+    private static ButtonBarBuilder2 createRightToLeftBuilder() {
+        ButtonBarBuilder2 builder = new ButtonBarBuilder2();
         builder.setLeftToRightButtonOrder(false);
         return builder;
     }
