@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -34,6 +34,7 @@ import javax.swing.*;
 
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.layout.FormLayout;
+import com.jgoodies.forms.tutorial.util.TutorialApplication;
 
 /**
  * Combines the FormLayout with the PanelBuilder.
@@ -46,14 +47,13 @@ import com.jgoodies.forms.layout.FormLayout;
  * The recommended style is demonstrated in the {@link DefaultFormBuilderExample}.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.21 $
  *
  * @see	PlainExample
  * @see	RowCounterExample
  * @see	DefaultFormBuilderExample
  */
-
-public final class DynamicRowsExample {
+public final class DynamicRowsExample extends TutorialApplication {
 
     private JTextField identifierField;
     private JTextField ptiField;
@@ -71,26 +71,24 @@ public final class DynamicRowsExample {
     private JCheckBox  slotsCheckBox;
 
 
+    // Launching **************************************************************
+
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Forms Tutorial :: Dynamic Rows");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new DynamicRowsExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        frame.setVisible(true);
+        TutorialApplication.launch(DynamicRowsExample.class, args);
+    }
+
+
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Forms Tutorial :: Dynamic Rows");
+        frame.getContentPane().add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
     // Component Creation and Initialization **********************************
 
     /**
-     *  Creates and intializes the UI components.
+     *  Creates and initializes the UI components.
      */
     private void initComponents() {
         identifierField = new JTextField();
@@ -146,51 +144,51 @@ public final class DynamicRowsExample {
         builder.addSeparator("Segment");
         builder.nextLine(2);
 
-        builder.addLabel("Identifier");       builder.nextColumn(2);
+        builder.addLabel("Identifier:");       builder.nextColumn(2);
         builder.add(identifierField);
         builder.nextLine(2);
 
-        builder.addLabel("PTI/kW");           builder.nextColumn(2);
-        builder.add(ptiField);                builder.nextColumn(2);
-        builder.addLabel("Power/kW");         builder.nextColumn(2);
+        builder.addLabel("PTI/kW:");           builder.nextColumn(2);
+        builder.add(ptiField);                 builder.nextColumn(2);
+        builder.addLabel("Power/kW:");         builder.nextColumn(2);
         builder.add(powerField);
         builder.nextLine(2);
 
-        builder.addLabel("len/mm");           builder.nextColumn(2);
+        builder.addLabel("len/mm:");           builder.nextColumn(2);
         builder.add(lenField);
         builder.nextLine(2);
 
         builder.addSeparator("Diameters");
         builder.nextLine(2);
 
-        builder.addLabel("da/mm");            builder.nextColumn(2);
-        builder.add(daField);                 builder.nextColumn(2);
-        builder.addLabel("di/mm");            builder.nextColumn(2);
+        builder.addLabel("da/mm:");            builder.nextColumn(2);
+        builder.add(daField);                  builder.nextColumn(2);
+        builder.addLabel("di/mm:");            builder.nextColumn(2);
         builder.add(diField);
         builder.nextLine(2);
 
-        builder.addLabel("da2/mm");           builder.nextColumn(2);
-        builder.add(da2Field);                builder.nextColumn(2);
-        builder.addLabel("di2/mm");           builder.nextColumn(2);
+        builder.addLabel("da2/mm:");           builder.nextColumn(2);
+        builder.add(da2Field);                 builder.nextColumn(2);
+        builder.addLabel("di2/mm:");           builder.nextColumn(2);
         builder.add(di2Field);
 
         builder.nextLine(2);
-        builder.addLabel("R/mm");             builder.nextColumn(2);
-        builder.add(rField);                  builder.nextColumn(2);
-        builder.addLabel("D/mm");             builder.nextColumn(2);
+        builder.addLabel("R/mm:");             builder.nextColumn(2);
+        builder.add(rField);                   builder.nextColumn(2);
+        builder.addLabel("D/mm:");             builder.nextColumn(2);
         builder.add(dField);
         builder.nextLine(2);
 
         builder.addSeparator("Criteria");
         builder.nextLine(2);
 
-        builder.addLabel("Location");         builder.nextColumn(2);
-        builder.add(locationCombo);           builder.nextColumn(2);
-        builder.addLabel("k-factor");         builder.nextColumn(2);
+        builder.addLabel("Location:");         builder.nextColumn(2);
+        builder.add(locationCombo);            builder.nextColumn(2);
+        builder.addLabel("k-factor:");         builder.nextColumn(2);
         builder.add(kFactorField);
         builder.nextLine(2);
 
-        builder.addLabel("Holes");            builder.nextColumn(2);
+        builder.addLabel("Holes:");            builder.nextColumn(2);
         builder.setColumnSpan(5);
         builder.add(holesCheckBox);
         builder.setColumnSpan(1);
