@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2009 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -38,33 +38,35 @@ import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.ButtonBarFactory;
 import com.jgoodies.forms.layout.CellConstraints;
 import com.jgoodies.forms.layout.FormLayout;
+import com.jgoodies.forms.tutorial.util.TutorialApplication;
 
 /**
  * Demonstrates the use of Factories as provided by the Forms framework.
  *
  * @author	Karsten Lentzsch
- * @version $Revision: 1.15 $
+ * @version $Revision: 1.20 $
  *
  * @see	ButtonBarFactory
  */
-public final class ButtonBarFactoryExample {
+public final class ButtonBarFactoryExample extends TutorialApplication {
+
+
+    // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Forms Tutorial :: ButtonBarFactory");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new ButtonBarFactoryExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        frame.setVisible(true);
+        TutorialApplication.launch(ButtonBarFactoryExample.class, args);
     }
 
 
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Forms Tutorial :: ButtonBarFactory");
+        frame.getContentPane().add(buildPanel());
+        packAndShowOnScreenCenter(frame);
+    }
+
+
+    // Building ***************************************************************
+
     public JComponent buildPanel() {
         JTabbedPane tabbedPane = new JTabbedPane();
         tabbedPane.putClientProperty("jgoodies.noContentBorder", Boolean.TRUE);
@@ -167,8 +169,8 @@ public final class ButtonBarFactoryExample {
     private Component buildAddRemovePropertiesPanel() {
         FormLayout layout = new FormLayout(
                         "fill:default:grow",
-                        "fill:p:grow, 4dlu, p, 14dlu, " +
-                        "fill:p:grow, 4dlu, p");
+                        "fill:p:grow, $rgap, p, 14dlu, " +
+                        "fill:p:grow, $rgap, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
@@ -176,14 +178,14 @@ public final class ButtonBarFactoryExample {
         builder.add(new JScrollPane(new JTextArea()));
         builder.nextRow(2);
         builder.add(ButtonBarFactory.buildAddRemovePropertiesLeftBar(
-            new JButton("Add\u2026"), new JButton("Remove"), new JButton("Properties\u2026")
+            new JButton("Add\u2026"), new JButton("Remove"), new JButton("Properties")
         ));
         builder.nextRow(2);
 
         builder.add(new JScrollPane(new JTextArea()));
         builder.nextRow(2);
         builder.add(ButtonBarFactory.buildAddRemovePropertiesRightBar(
-            new JButton("Add\u2026"), new JButton("Remove"), new JButton("Properties\u2026")
+            new JButton("Add\u2026"), new JButton("Remove"), new JButton("Properties")
         ));
         return builder.getContainer();
     }
@@ -191,7 +193,7 @@ public final class ButtonBarFactoryExample {
     private Component buildAddRemovePanel() {
         FormLayout layout = new FormLayout(
                         "fill:default:grow, 9dlu, fill:default:grow",
-                        "fill:p:grow, 4dlu, p");
+                        "fill:p:grow, $rgap, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
